@@ -1,5 +1,14 @@
 use crate::app::InitHook;
 
+const FZF_COMPLETE_OPTS: &str = "\
+    --bind=ctrl-z:ignore \
+    --exit-0 \
+    --height=35% \
+    --inline-info \
+    --no-sort \
+    --reverse \
+    --select-1";
+
 #[derive(Debug, Eq, PartialEq)]
 pub struct Opts<'a> {
     pub cmd: Option<&'a str>,
@@ -32,15 +41,15 @@ make_template!(Powershell, "powershell.txt");
 make_template!(Xonsh, "xonsh.txt");
 make_template!(Zsh, "zsh.txt");
 
-#[cfg(feature = "shell_tests")]
+#[cfg(feature = "nix")]
 #[cfg(test)]
 mod tests {
-    use super::*;
-
     use askama::Template;
     use assert_cmd::Command;
     use rstest::rstest;
 
+    use super::*;
+
     #[rstest]
     fn bash_bash(
         #[values(None, Some("z"))] cmd: Option<&str>,
@@ -50,9 +59,8 @@ mod tests {
     ) {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let source = Bash(&opts).render().unwrap();
-
         Command::new("bash")
-            .args(&["--noprofile", "--norc", "-c", &source])
+            .args(&["--noprofile", "--norc", "-e", "-u", "-o", "pipefail", "-c", &source])
             .assert()
             .success()
             .stdout("")
@@ -108,21 +116,14 @@ mod tests {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let mut source = String::new();
 
-        // Filter out lines using edit:*, since those functions
-        // are only available in the interactive editor.
-        for line in
-            Elvish(&opts).render().unwrap().split('\n').filter(|line| !line.contains("edit:"))
-        {
+        // Filter out lines using edit:*, since those functions are only available in the
+        // interactive editor.
+        for line in Elvish(&opts).render().unwrap().split('\n').filter(|line| !line.contains("edit:")) {
             source.push_str(line);
             source.push('\n');
         }
 
-        Command::new("elvish")
-            .args(&["-c", &source, "-norc"])
-            .assert()
-            .success()
-            .stdout("")
-            .stderr("");
+        Command::new("elvish").args(&["-c", &source, "-norc"]).assert().success().stdout("").stderr("");
     }
 
     #[rstest]
@@ -161,9 +162,8 @@ mod tests {
         let tempdir = tempfile::tempdir().unwrap();
         let tempdir = tempdir.path().to_str().unwrap();
 
-        Command::new("fish")
+        Command::new("fish_indent")
             .env("HOME", tempdir)
-            .args(&["--command", "fish_indent", "--private"])
             .write_stdin(source.to_string())
             .assert()
             .success()
@@ -184,12 +184,8 @@ mod tests {
         let tempdir = tempfile::tempdir().unwrap();
         let tempdir = tempdir.path().to_str().unwrap();
 
-        let assert = Command::new("nu")
-            .env("HOME", tempdir)
-            .args(&["--commands", &source])
-            .assert()
-            .success()
-            .stderr("");
+        let assert =
+            Command::new("nu").env("HOME", tempdir).args(&["--commands", &source]).assert().success().stderr("");
 
         if opts.hook != InitHook::Pwd {
             assert.stdout("");
@@ -197,7 +193,7 @@ mod tests {
     }
 
     #[rstest]
-    fn posix_bashposix(
+    fn posix_bash(
         #[values(None, Some("z"))] cmd: Option<&str>,
         #[values(InitHook::None, InitHook::Prompt, InitHook::Pwd)] hook: InitHook,
         #[values(false, true)] echo: bool,
@@ -207,11 +203,10 @@ mod tests {
         let source = Posix(&opts).render().unwrap();
 
         let assert = Command::new("bash")
-            .args(&["--posix", "--noprofile", "--norc", "-c", &source])
+            .args(&["--posix", "--noprofile", "--norc", "-e", "-u", "-o", "pipefail", "-c", &source])
             .assert()
             .success()
             .stderr("");
-
         if opts.hook != InitHook::Pwd {
             assert.stdout("");
         }
@@ -227,7 +222,7 @@ mod tests {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let source = Posix(&opts).render().unwrap();
 
-        let assert = Command::new("dash").args(&["-c", &source]).assert().success().stderr("");
+        let assert = Command::new("dash").args(&["-c", &source, "-e", "-u"]).assert().success().stderr("");
         if opts.hook != InitHook::Pwd {
             assert.stdout("");
         }
@@ -302,12 +297,7 @@ mod tests {
         let mut source = Xonsh(&opts).render().unwrap();
         source.push('\n');
 
-        Command::new("black")
-            .args(&["--check", "--diff", "-"])
-            .write_stdin(source)
-            .assert()
-            .success()
-            .stdout("");
+        Command::new("black").args(&["--check", "--diff", "-"]).write_stdin(source).assert().success().stdout("");
     }
 
     #[rstest]
@@ -320,7 +310,7 @@ mod tests {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let source = Xonsh(&opts).render().unwrap();
 
-        Command::new("mypy").args(&["--command", &source]).assert().success().stderr("");
+        Command::new("mypy").args(&["--command", &source, "--strict"]).assert().success().stderr("");
     }
 
     #[rstest]
@@ -334,16 +324,7 @@ mod tests {
         let mut source = Xonsh(&opts).render().unwrap();
         source.push('\n');
 
-        let tempdir = tempfile::tempdir().unwrap();
-        let tempdir = tempdir.path().to_str().unwrap();
-
-        Command::new("pylint")
-            .args(&["--from-stdin", "zoxide"])
-            .env("HOME", tempdir)
-            .write_stdin(source)
-            .assert()
-            .success()
-            .stderr("");
+        Command::new("pylint").args(&["--from-stdin", "zoxide"]).write_stdin(source).assert().success().stderr("");
     }
 
     #[rstest]
@@ -378,8 +359,7 @@ mod tests {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let source = Zsh(&opts).render().unwrap();
 
-        // ShellCheck doesn't support zsh yet.
-        // https://github.com/koalaman/shellcheck/issues/809
+        // ShellCheck doesn't support zsh yet: https://github.com/koalaman/shellcheck/issues/809
         Command::new("shellcheck")
             .args(&["--enable", "all", "--shell", "bash", "-"])
             .write_stdin(source)
@@ -400,7 +380,7 @@ mod tests {
         let source = Zsh(&opts).render().unwrap();
 
         Command::new("zsh")
-            .args(&["-c", &source, "--no-globalrcs", "--no-rcs"])
+            .args(&["-c", &source, "-e", "-u", "-o", "pipefail", "--no-globalrcs", "--no-rcs"])
             .assert()
             .success()
             .stdout("")
